@@ -45,14 +45,14 @@ def test_dispatch(request):
 def noop():
     return True
 
-def main():
+def main(port):
     httpd = HTTPDaemon("127.0.0.1", port)
     httpd.register_prefix("/index", test_dispatch)
     event.timeout(1, noop)
     event.dispatch()
 
-def profile():
+def profile(port):
     import hotshot
     prof = hotshot.Profile("orbited_http_test.profile")
-    prof.runcall(main)
-    prof.close()
\ No newline at end of file
+    prof.runcall(main, port)
+    prof.close()
