@@ -1,6 +1,5 @@
 import pprint
 from dez.http.application import HTTPApplication
-port = 8888
 
 def simple_app(environ, start_response):
     print 'POST DATA:'
@@ -8,7 +7,7 @@ def simple_app(environ, start_response):
     print '===='
     pprint.pprint(environ)
     
-def main():
+def main(port):
     httpd = HTTPApplication("127.0.0.1", port)
     httpd.add_wsgi_rule("/", simple_app)
     httpd.start()
