@@ -1,8 +1,4 @@
-import rel
-rel.override()
-rel.initialize(["epoll"])
 from dez.http.application import HTTPApplication
-port = 8888
 
 def simple_app(environ, start_response):
     """Simplest possible application object"""
@@ -11,7 +7,7 @@ def simple_app(environ, start_response):
     start_response(status, response_headers)
     return ['Hello world!\n']
     
-def main():
+def main(port):
     httpd = HTTPApplication("127.0.0.1", port)
     httpd.add_wsgi_rule("/", simple_app)
-    httpd.start()
\ No newline at end of file
+    httpd.start()
